import { InjectionToken, Injectable, Injector, Pipe, NgModule } from '@angular/core';
import { __decorate, __metadata } from 'tslib';
import { HttpErrorResponse, HTTP_INTERCEPTORS, HttpClientModule } from '@angular/common/http';
import { I18NEXT_SERVICE } from 'angular-i18next';
import { tap } from 'rxjs/operators';

const HTTP_STATUS_DICTIONARY = new InjectionToken('HTTP_STATUS_LOCALE_KEYS');

let I18NextErrorInterceptor = class I18NextErrorInterceptor {
    constructor(injector // https://github.com/angular/angular/issues/18224
    ) {
        this.injector = injector;
        this.statusKeys = this.injector.get(HTTP_STATUS_DICTIONARY);
    }
    intercept(req, next) {
        return next.handle(req).pipe(tap((event) => { }, (err) => {
            if (err instanceof HttpErrorResponse) {
                this.HandleErrorMessage(err);
            }
        }));
    }
    HandleErrorMessage(errorResponse) {
        if (!errorResponse) {
            return errorResponse;
        }
        let errorEntity;
        // if error is object or json string that can be parsed
        try {
            if (errorResponse.error instanceof Object) {
                errorEntity = errorResponse.error;
            }
            else {
                errorEntity = JSON.parse(errorResponse.error);
            }
        }
        catch (ex) { }
        // if object got message: server localized message by himself (no need to translate)
        if (!(errorEntity && errorEntity.message)) {
            errorEntity = { message: this.GetLocalizedStatusMessage(errorResponse.status) };
        }
        // modify error response with client localized message
        return new HttpErrorResponse(Object.assign(errorResponse, { error: errorEntity }));
    }
    GetLocalizedStatusMessage(status = undefined) {
        const i18nextService = this.injector.get(I18NEXT_SERVICE);
        let errorKey = this.statusKeys[status] || this.statusKeys.default;
        return i18nextService.t(errorKey);
    }
};
I18NextErrorInterceptor = __decorate([
    Injectable(),
    __metadata("design:paramtypes", [Injector // https://github.com/angular/angular/issues/18224
    ])
], I18NextErrorInterceptor);

let HttpErrorResponseMessage = class HttpErrorResponseMessage {
    transform(httpErrorResp) {
        if (!httpErrorResp || !httpErrorResp.error) {
            return null;
        }
        return httpErrorResp.error.message;
    }
};
HttpErrorResponseMessage = __decorate([
    Injectable(),
    Pipe({
        name: 'httpErrorResponseMessage',
    })
], HttpErrorResponseMessage);

var I18NextErrorInterceptorModule_1;
const DEFAULT_STATUS_KEYS = {
    400: 'http_error:validation_error',
    401: 'http_error:not_authorized',
    403: 'http_error:access_denied',
    500: 'http_error:internal_server_error',
    'default': 'http_error:unknown_server_error'
};
const declarations = [
    HttpErrorResponseMessage
];
let I18NextErrorInterceptorModule = I18NextErrorInterceptorModule_1 = class I18NextErrorInterceptorModule {
    static forRoot(httpStatusDictionary = null) {
        return {
            ngModule: I18NextErrorInterceptorModule_1,
            providers: [
                {
                    provide: HTTP_STATUS_DICTIONARY,
                    useValue: httpStatusDictionary || DEFAULT_STATUS_KEYS
                },
                {
                    provide: HTTP_INTERCEPTORS,
                    useClass: I18NextErrorInterceptor,
                    multi: true
                }
            ]
        };
    }
};
I18NextErrorInterceptorModule = I18NextErrorInterceptorModule_1 = __decorate([
    NgModule({
        imports: [
            HttpClientModule
        ],
        declarations: declarations,
        exports: declarations,
        providers: [
            HttpErrorResponseMessage
        ]
    })
], I18NextErrorInterceptorModule);

/**
 * Generated bundle index. Do not edit.
 */

export { DEFAULT_STATUS_KEYS, HTTP_STATUS_DICTIONARY, HttpErrorResponseMessage, I18NextErrorInterceptorModule, I18NextErrorInterceptor as ɵa };
//# sourceMappingURL=angular-i18next-error-interceptor.js.map
